pub enum Entry<'a, K, V, S = RandomState> {
Occupied(OccupiedEntry<'a, K, V, S>),
Vacant(VacantEntry<'a, K, V, S>),
}Expand description
A view into a single entry in a map, similar to
std::collections::hash_map::Entry.
Variants
Occupied(OccupiedEntry<'a, K, V, S>)
Vacant(VacantEntry<'a, K, V, S>)
Implementations
Sourceimpl<'a, K, V, S> Entry<'a, K, V, S>
impl<'a, K, V, S> Entry<'a, K, V, S>
Sourcepub fn or_insert(self, default: V) -> &'a mut V
pub fn or_insert(self, default: V) -> &'a mut V
Ensures a value is in the entry by inserting default if vacant,
and returns a mutable reference to the value in the entry.
Sourcepub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
pub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut V
Ensures a value is in the entry by inserting the result of default
if vacant, and returns a mutable reference to the value in the entry.
Sourcepub fn or_default(self) -> &'a mut Vwhere
V: Default,
pub fn or_default(self) -> &'a mut Vwhere
V: Default,
Ensures a value is in the entry by inserting Default::default
if vacant, and returns a mutable reference to the value in the entry.
Sourcepub fn and_modify<F: FnOnce(&mut V)>(self, f: F) -> Self
pub fn and_modify<F: FnOnce(&mut V)>(self, f: F) -> Self
Provides in-place mutable access to an occupied entry before any potential insertion.