pub struct OccupiedEntry<'a, K, V, S = RandomState> { /* private fields */ }Expand description
A view into an occupied entry in a LinkedHashMap.
Implementations
Sourceimpl<'a, K, V, S> OccupiedEntry<'a, K, V, S>
impl<'a, K, V, S> OccupiedEntry<'a, K, V, S>
Sourcepub fn remove_entry(self) -> (K, V)
pub fn remove_entry(self) -> (K, V)
Removes the entry from the map and returns the key-value pair.